@@ -1,5 +1,5 @@
 import pandas as pd
-import re, os
+import re, os, pkg_resources
 
 class Phonetic_Manipulation():
 	"""
@@ -106,9 +106,8 @@ class Phonetic_Manipulation():
 		pl : list
 			an optional list of phones already found in the data
 		"""
-		dir_path = os.path.dirname(os.path.realpath(__file__))
-		phoneset = dir_path + '/data/phoneset_mapping.csv'
-		diacritics = dir_path + '/data/diacritic_mappings.csv'
+		phoneset = pkg_resources.resource_stream(__name__, '/data/phoneset_mapping.csv')
+		diacritics = pkg_resources.resource_stream(__name__, '/data/diacritic_mappings.csv')
 
 		self.ps = pd.read_csv(phoneset)
 		self.dm = pd.read_csv(diacritics)
